package com.jeromesaltmarsh.flutter_plugin_helpcrunch

import androidx.annotation.NonNull
import com.helpcrunch.library.core.HelpCrunch
import com.helpcrunch.library.core.models.user.HCUser

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar

/** FlutterPluginHelpcrunchPlugin */
class FlutterPluginHelpcrunchPlugin: FlutterPlugin, MethodCallHandler {

  private lateinit var channel : MethodChannel

  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    channel = MethodChannel(flutterPluginBinding.binaryMessenger, "flutter.native/helpcrunch")
    channel.setMethodCallHandler(this)
  }

  override fun onMethodCall(@NonNull call: MethodCall, @NonNull result: Result) {

    if(call.method == "logout"){
      HelpCrunch.logout()
      return;
    }

    if(call.method == "initialize"){

      val org : String? = call.argument("organization")

      if(org != null){

        val appId: Int? = call.argument("appId")

        if(appId != null){

          val appSecret: String? = call.argument("appSecret")

          if(appSecret != null){
            HelpCrunch.initialize(
                    org,
                    appId,
                    appSecret,
                    HCUser.from(mutableMapOf("email" to "jerome.salmarsh"))
            )

          }
        }
      }
    } else
    if (call.method == "showChatScreen") {
      HelpCrunch.showChatScreen()
    }

    result.success("Hello World")
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    channel.setMethodCallHandler(null)
  }
}
